from abc import ABC, abstractmethod

from pygame.surface import Surface

from ..MouseButtons import MouseButtons
from ..MouseWheel import MouseWheel
from ..Theme import Theme


class GameMode(ABC):

    def __init__(self, theme: Theme):
        self.__theme = theme

    @property
    def theme(self):
        return self.__theme

    @abstractmethod
    def processInput(self):
        raise NotImplementedError()

    @abstractmethod
    def update(self):
        raise NotImplementedError()

    @abstractmethod
    def render(self, surface: Surface):
        raise NotImplementedError()

    # Keyboard
    def keyDown(self, key: int):
        pass

    def keyUp(self, key: int):
        pass

    # Mouse handling

    def mouseEnter(self, mouseX: int, mouseY: int, buttons: MouseButtons):
        pass

    def mouseLeave(self):
        pass

    def mouseButtonDown(self, mouseX: int, mouseY: int, buttons: MouseButtons):
        pass

    def mouseButtonUp(self, mouseX: int, mouseY: int, buttons: MouseButtons):
        pass

    def mouseWheel(self, mouseX: int, mouseY: int, buttons: MouseButtons, wheel: MouseWheel):
        pass

    def mouseMove(self, mouseX: int, mouseY: int, buttons: MouseButtons):
        pass